package com.pj.project.tb_business;

import java.util.List;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.util.StrUtil;
import com.pj.constants.UserTypeEnum;
import com.pj.project.tb_business_item.TbBusinessItem;
import com.pj.project.tb_business_item.TbBusinessItemService;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;

import javax.annotation.Resource;


/**
 * Controller: tb_business -- 入境登记
 * @author qzy 
 */
@RestController
@RequestMapping("/TbBusiness/")
public class TbBusinessController {

	/** 底层 Service 对象 */
	@Autowired
	TbBusinessService tbBusinessService;
	@Resource
	private TbBusinessItemService tbBusinessItemService;

	/** 增 */  
	@RequestMapping("add")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	@Transactional(rollbackFor = Exception.class)
	public AjaxJson add(TbBusiness t){
		tbBusinessService.addOrUpdate(t);
		t = tbBusinessService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */  
	@RequestMapping("delete")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	public AjaxJson delete(String id){
		tbBusinessService.removeById(id);
		tbBusinessItemService.removeByBusinessId(id);
		return AjaxJson.getSuccess();
	}
	
	/** 删 - 根据id列表 */  
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
		ids.forEach(id->{
			tbBusinessItemService.removeByBusinessId(id+"");
		});
		int line = SP.publicMapper.deleteByIds(TbBusiness.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}
	
	/** 改 */  
	@RequestMapping("update")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	public AjaxJson update(TbBusiness t){
		tbBusinessService.addOrUpdate(t);
		return AjaxJson.getSuccess();
	}
	/** 确认业务 */
	@RequestMapping("confirm")
	public AjaxJson confirm(){
		if (!StpUtil.hasPermissionAnd(TbBusiness.PERMISSION_CONFIRM)&&!
				StrUtil.equals(StpUserUtil.getCustomerId(), UserTypeEnum.PLATFORM_ADMIN.getCustomerId())) {
			return AjaxJson.getError("无确认业务权限");
		}
		SoMap so = SoMap.getRequestSoMap();
		List<String>ids=so.getListByComma("ids",String.class);
		tbBusinessService.confirm(ids);
		return AjaxJson.getSuccess();
	}
	/** 确认业务 */
	@RequestMapping("adminConfirmPay")
	public AjaxJson adminConfirmPay(){
		if (!StrUtil.equals(StpUserUtil.getCustomerId(), UserTypeEnum.PLATFORM_ADMIN.getCustomerId())) {
			return AjaxJson.getError("无确认支付权限");
		}
		SoMap so = SoMap.getRequestSoMap();
		List<String>ids=so.getListByComma("ids",String.class);
		tbBusinessService.adminConfirmPay(ids);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */  
	@RequestMapping("getById")
	public AjaxJson getById(String id){
		TbBusiness t = tbBusinessService.getById(id);
		List<TbBusinessItem>items=tbBusinessItemService.findByBusinessId(id);
		t.setItems(items);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */  
	@RequestMapping("getList")
	public AjaxJson getList() { 
		SoMap so = SoMap.getRequestSoMap();
		String currentCustomerId=StpUserUtil.getCustomerId();
		if (!currentCustomerId.equals(UserTypeEnum.PLATFORM_ADMIN.getCustomerId())) {
			so.put("customerId",currentCustomerId);
		}
		List<TbBusiness> list = tbBusinessService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}

	/** 改 */
	@RequestMapping("pay")
	public AjaxJson pay(){
		if (!StpUtil.hasPermissionAnd("tb-business-pay")&&!
		StrUtil.equals(StpUserUtil.getCustomerId(), UserTypeEnum.PLATFORM_ADMIN.getCustomerId())) {
			return AjaxJson.getError("无支付权限");
		}
		SoMap so = SoMap.getRequestSoMap();
		String id=so.getString("id");
		String payTicket=so.getString("payTicket");
		tbBusinessService.pay(id,payTicket);
		return AjaxJson.getSuccess();
	}
	
	
	// ------------------------- 前端接口 -------------------------
	
	
	/** 改 - 不传不改 [G] */
	@RequestMapping("updateByNotNull")
	public AjaxJson updateByNotNull(Long id){
		AjaxError.throwBy(true, "如需正常调用此接口，请删除此行代码");
		// 鉴别身份，是否为数据创建者 
		long userId = SP.publicMapper.getColumnByIdToLong(TbBusiness.TABLE_NAME, "user_id", id);
		AjaxError.throwBy(userId != StpUserUtil.getLoginIdAsLong(), "此数据您无权限修改");
		// 开始修改 (请只保留需要修改的字段)
		SoMap so = SoMap.getRequestSoMap();
		so.clearNotIn("id", "customerId", "customerName", "no", "cardNo", "cardSize", "netWeight", "goodsName", "goodsCode", "driverName", "driverId", "driverPhone", "driverIdCard", "payTicket", "expectInDay", "realInDay", "realInTime", "payStatus", "payTime", "payType", "outDayTime", "partMoney", "partTime").clearNull().humpToLineCase();	
		int line = SP.publicMapper.updateBySoMapById(TbBusiness.TABLE_NAME, so, id);
		return AjaxJson.getByLine(line);
	}
	
	
	
	
	
	

}
