package com.pj.project.tb_costomer;

import java.util.List;

import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_costomer -- 客户管理
 * @author qzy 
 */
@RestController
@RequestMapping("/TbCostomer/")
public class TbCostomerController {

	/** 底层 Service 对象 */
	@Autowired
	TbCostomerService tbCostomerService;

	/** 增 */  
	@RequestMapping("add")
	@SaCheckPermission(TbCostomer.PERMISSION_CODE)
	@Transactional(rollbackFor = Exception.class)
	public AjaxJson add(TbCostomer t){
		tbCostomerService.add(t);
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */  
	@RequestMapping("delete")
	@SaCheckPermission(TbCostomer.PERMISSION_CODE)
	public AjaxJson delete(String id){
		int line = tbCostomerService.delete(id);
		return AjaxJson.getByLine(line);
	}
	
	/** 删 - 根据id列表 */  
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbCostomer.PERMISSION_CODE)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
		ids.forEach(id->tbCostomerService.delete(id+""));
		return AjaxJson.getByLine(1);
	}
	
	/** 改 */  
	@RequestMapping("update")
	@SaCheckPermission(TbCostomer.PERMISSION_CODE)
	public AjaxJson update(TbCostomer t){
		int line = tbCostomerService.update(t);
		return AjaxJson.getByLine(line);
	}

	/** 查 - 根据id */  
	@RequestMapping("getById")
	public AjaxJson getById(String id){
		TbCostomer t = tbCostomerService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */  
	@RequestMapping("getList")
	public AjaxJson getList() { 
		SoMap so = SoMap.getRequestSoMap();
		List<TbCostomer> list = tbCostomerService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}

    /** 查集合 - 客户登录时查询自己 */
    @RequestMapping("getOwnList")
    public AjaxJson getOwnList() {
        SoMap so = SoMap.getRequestSoMap();
        so.put("id", StpUserUtil.getCustomerId());
        List<TbCostomer> list = tbCostomerService.getList(so.startPage());
        return AjaxJson.getPageData(so.getDataCount(), list);
    }
	
	
	
	/** 改 - 状态(0=否,1=是) */  
	@RequestMapping("updateStatus")
	@SaCheckPermission(TbCostomer.PERMISSION_CODE)
	public AjaxJson updateStatus(String id, int value){
		tbCostomerService.updateStatus(id,value);

		return AjaxJson.getByLine(1);
	}


	@RequestMapping("getCurrentCustomerId")
	@SaCheckPermission(TbCostomer.PERMISSION_CODE)
	public AjaxJson getCurrentCustomer(){
		String id=StpUserUtil.getCustomerId();
		return AjaxJson.getSuccessData(id);
	}

	@RequestMapping("judge")
	@SaCheckPermission(TbCostomer.PERMISSION_CODE)
	public AjaxJson judge(){
		SoMap so = SoMap.getRequestSoMap();
		tbCostomerService.judge(so.getString("id"),so.getInt("judgeStatus"),so.getString("judgeContent"));
		return AjaxJson.getSuccess();
	}


	
	
	
	
	

}
