package com.pj.project.tb_costomer;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.stream.Collectors;

import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.pj.constants.RoleEnum;
import com.pj.project.tb_district.TbDistrict;
import com.pj.project.tb_district.TbDistrictService;
import com.pj.project4sp.SP;
import com.pj.project4sp.admin.SpAdminMapper;
import com.pj.project4sp.role.SpRole;
import com.pj.project4sp.role.SpRoleMapper;
import com.pj.project4sp.role4permission.SpRolePermissionMapper;
import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.pj.utils.sg.*;

import javax.annotation.Resource;

/**
 * Service: tb_costomer -- 客户管理
 *
 * @author qzy
 */
@Service
public class TbCostomerService extends ServiceImpl<TbCostomerMapper, TbCostomer> implements IService<TbCostomer> {

    /**
     * 底层 Mapper 对象
     */
    @Autowired
    TbCostomerMapper tbCostomerMapper;
    @Resource
    private SpRoleMapper spRoleMapper;
    @Resource
    private SpRolePermissionMapper spRolePermissionMapper;
    @Resource
    private TbDistrictService tbDistrictService;
    @Resource
    private SpAdminMapper spAdminMapper;

    /**
     * 增
     */
    int add(TbCostomer t) {
        t.setCreareTime(new Date()).setJudgeContent("平台创建，直接通过").setJudgeTime(new Date());
        List<TbDistrict> districts = tbDistrictService.listByIds(StrUtil.splitTrim(t.getAddressIds(), ","));
        String address = districts.stream().map(TbDistrict::getDistrict).collect(Collectors.joining(""));
        t.setAddressStr(address);
        this.save(t);
        List<RoleEnum> roleEnums = RoleEnum.getCustomerInitRoleList();
        roleEnums.forEach(roleEnum -> {
            SpRole spRole = new SpRole();
            spRole.setCustomerId(t.getId()).setInfo(roleEnum.getName())
                    .setName(roleEnum.getName()).setType(roleEnum.getType());
            spRoleMapper.add(spRole);
            long roleId = SP.publicMapper.getPrimarykey();
            spRolePermissionMapper.saveRolePer(roleId, roleEnum.getPerCode());
        });
        return 1;
    }

    /**
     * 删
     */
    int delete(String id) {
        SoMap soMap = SoMap.getRequestSoMap();
        soMap.put("customerId", id);
        List<SpRole> roles = spRoleMapper.getList(soMap);
        spRoleMapper.removeByCustomerId(id);
        spRolePermissionMapper.removeByRoleIds(roles.stream().map(SpRole::getId).collect(Collectors.toList()));
        spAdminMapper.removeByCustomerId(id);
        return tbCostomerMapper.delete(id);
    }

    /**
     * 改
     */
    int update(TbCostomer t) {
        List<TbDistrict> districts = tbDistrictService.listByIds(StrUtil.splitTrim(t.getAddressIds(), ","));
        String address = districts.stream().map(TbDistrict::getDistrict).collect(Collectors.joining(""));
        t.setAddressStr(address);
        this.updateById(t);
        return 1;
    }



    /**
     * 查集合 - 根据条件（参数为空时代表忽略指定条件）
     */
    List<TbCostomer> getList(SoMap so) {
        return tbCostomerMapper.getList(so);
    }


    public int updateStatus(String id, int value) {
        int line = SP.publicMapper.updateColumnById(TbCostomer.TABLE_NAME, "status", value, id);
        int status=value==1?1:2;
        spAdminMapper.updateCustomerAdmin(id,status);
        return line;
    }

    public void judge(String id, int status,String judgeContent) {
      TbCostomer costomer=  this.getById(id);
      costomer.setJudgeContent(judgeContent)
              .setJudgeStatus(status).setJudgeTime(new Date());
      this.updateById(costomer);
    }
}
